Authorization class

Constructors

Authorization(int _id, String _name, List _roles)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateRole(dynamic role) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited